@@ -25,14 +25,14 @@ class GetQuotaApplicationRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'quotas', '2020-05-10', 'GetQuotaApplication','quotas')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ApplicationId(self):
+	def get_ApplicationId(self): # String
 		return self.get_body_params().get('ApplicationId')
 
-	def set_ApplicationId(self,ApplicationId):
-		self.add_body_params('ApplicationId', ApplicationId)
\ No newline at end of file
+	def set_ApplicationId(self, ApplicationId):  # String
+		self.add_body_params('ApplicationId', ApplicationId)
